Flask-Security
===================

.. image:: https://travis-ci.org/jwag956/flask-security.svg?branch=master
    :target: https://travis-ci.org/jwag956/flask-security

.. image:: https://coveralls.io/repos/github/jwag956/flask-security/badge.svg?branch=master
    :target: https://coveralls.io/github/jwag956/flask-security?branch=master

.. image:: https://img.shields.io/github/tag/jwag956/flask-security.svg
    :target: https://github.com/jwag956/flask-security/releases

.. image:: https://img.shields.io/pypi/dm/flask-security-too.svg
    :target: https://pypi.python.org/pypi/flask-security-too
    :alt: Downloads

.. image:: https://img.shields.io/github/license/jwag956/flask-security.svg
    :target: https://github.com/jwag956/flask-security/blob/master/LICENSE
    :alt: License

.. image:: https://readthedocs.org/projects/flask-security-too/badge/?version=latest
    :target: https://flask-security-too.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Quickly add security features to your Flask application.

Notes on this repo
------------------
This is a fork of mattupstate/flask-security starting with 3.0.0 master branch.

Goals
+++++
* Regain momentum for this critical piece of the Flask eco-system. To that end the
  the plan is to put out small, frequent releases starting with pulling the simplest
  and most obvious changes that have already been vetted in the upstream version, as
  well as other pull requests.
* Continue work to get Flask-Security to be usable from Single Page Applications,
  such as those built with Vue and Angular, that have no html forms
* Any other great ideas.

Contributing
++++++++++++
Issues and pull requests are welcome. Other maintainers are also welcome. Unlike
the upstream Flask-Security - issue pull requests against the *master* branch.


Resources
---------

- `Documentation <https://flask-security-too.readthedocs.io/>`_
- `Issue Tracker <https://github.com/jwag956/flask-security/issues>`_
- `Code <https://github.com/jwag956/flask-security/>`_
